@@ -2,4 +2,4 @@ from django.apps import AppConfig
 
 
 class DjangoSassConfig(AppConfig):
-    name = 'django_sass'
+    name = "django_sass"
