@@ -2,4 +2,4 @@ from django.apps import AppConfig
 
 
 class App1Config(AppConfig):
-    name = 'app1'
+    name = "app1"
