@@ -2,4 +2,4 @@ from django.apps import AppConfig
 
 
 class App2Config(AppConfig):
-    name = 'app2'
+    name = "app2"
